==> aws-android-sdk-cognitoidentityprovider-2.2.15-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/transform/EnhanceAuthResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.cognitoidentityprovider.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * Enhance Auth Result JSON Unmarshaller
 */
public class EnhanceAuthResultJsonUnmarshaller implements Unmarshaller<EnhanceAuthResult, JsonUnmarshallerContext> {

    public EnhanceAuthResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        EnhanceAuthResult enhanceAuthResult = new EnhanceAuthResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            
            if (name.equals("AuthenticationResult")) {
                enhanceAuthResult.setAuthenticationResult(AuthenticationResultTypeJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            {
                reader.skipValue();
            }
            
        }
        reader.endObject();
        
        return enhanceAuthResult;
    }

    private static EnhanceAuthResultJsonUnmarshaller instance;
    public static EnhanceAuthResultJsonUnmarshaller getInstance() {
        if (instance == null) instance = new EnhanceAuthResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-cognitoidentityprovider-2.2.20-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/transform/EnhanceAuthResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model.transform;

import com.amazonaws.services.cognitoidentityprovider.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response EnhanceAuthResult
 */
public class EnhanceAuthResultJsonUnmarshaller implements
        Unmarshaller<EnhanceAuthResult, JsonUnmarshallerContext> {

    public EnhanceAuthResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        EnhanceAuthResult enhanceAuthResult = new EnhanceAuthResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("AuthenticationResult")) {
                enhanceAuthResult.setAuthenticationResult(AuthenticationResultTypeJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return enhanceAuthResult;
    }

    private static EnhanceAuthResultJsonUnmarshaller instance;

    public static EnhanceAuthResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new EnhanceAuthResultJsonUnmarshaller();
        return instance;
    }
}
